@@ -26,12 +26,15 @@ def getconfig():
 def initconfig(configfile, *defaultfiles):
     global CFG
     if CFG is None:
-        files = [configfile]
-        files.extend(defaultfiles)
+        if configfile is not None:
+            if not os.path.isfile(configfile):
+                raise ValueError, _("Configuration file doesn't exist or is not a file: {name}")\
+                                  .format(name=configfile)
+            files = [configfile]
+            files.extend(defaultfiles)
+        else:
+            files = list(defaultfiles)
         files.reverse()
-        if not os.path.isfile(configfile):
-            raise ValueError, _("Configuration file doesn't exist or is not a file: {name}")\
-                              .format(name=configfile)
         CFG = ConfigParser()
         CFG.read(files)
 
